import 'dart:collection';
import 'dart:io';

class Cooker {
  String templateFilePath;
  String targetFilePath;
  HashMap<String, String> contentVariables;
  String variablesPattern;

  Cooker(this.templateFilePath, this.targetFilePath,
      {this.contentVariables, this.variablesPattern = '{{%s}}'});

  void generate() {
    duplicateTemplate();

    if (hasContentVariables()) {
      replaceVariables();
    }
  }

  void duplicateTemplate() {
    final templateFile = File(templateFilePath);
    templateFile.copySync(targetFilePath);
  }

  void replaceVariables() {
    final targetFile = File(targetFilePath);
    var fileContent = targetFile.readAsStringSync();

    for (final contentVariable in contentVariables.entries) {
      final searchTerm = getVariableSearchTerm(contentVariable.key);

      fileContent = fileContent.replaceAll(searchTerm, contentVariable.value);
    }

    targetFile.writeAsStringSync(fileContent);
  }

  bool hasContentVariables() {
    return (contentVariables != null && contentVariables.isNotEmpty);
  }

  String getVariableSearchTerm(String varKey) {
    return variablesPattern.replaceAll('%s', varKey);
  }
}
